[Qa-jenkins-scm] [jenkins.debian.net] 01/01: reproducible: include build_date in tooltip

Holger Levsen holger at moszumanska.debian.org
Sun Aug 30 11:50:13 UTC 2015


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit 4ee8cc1ded42e0bcba2d79c8b2459c6bab29e1f1
Author: Holger Levsen <holger at layer-acht.org>
Date:   Sun Aug 30 13:49:49 2015 +0200

    reproducible: include build_date in tooltip
---
 bin/reproducible_html_packages.py | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/bin/reproducible_html_packages.py b/bin/reproducible_html_packages.py
index da63a87..dd86553 100755
--- a/bin/reproducible_html_packages.py
+++ b/bin/reproducible_html_packages.py
@@ -180,6 +180,7 @@ def gen_suites_links(package, current_suite, current_arch):
             if not status:  # The package is not available in that suite/arch
                 continue
             version = package.get_tested_version(s, a)
+            build_date = package.get_build_date(s, a)
             li_classes = ['suite']
             if s == current_suite and a == current_arch:
                 li_classes.append('active')
@@ -193,8 +194,8 @@ def gen_suites_links(package, current_suite, current_arch):
             icon = prefix + '<img src="/static/{icon}" alt="{status}" title="{status}"/>' + suffix
             html += icon.format(icon=join_status_icon(status)[1], status=status)
             html += (tab*2 + ' <a href="{}/{}/{}/{}.html" target="_parent"' + \
-                     ' title="{}: {}">{}</a>: {}\n').format(RB_PKG_URI,
-                     s, a, package.name, status, version, s, version)
+                     ' title="{}: {} on {}">{}</a>: {}\n').format(RB_PKG_URI,
+                     s, a, package.name, status, version, build_date, s, version)
             html += '</li>\n'
         html += tab + '</ul></li>'
     html += '</ul>\n'

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list